%define name 		ecell
%define version	 	3.1.105

# when compiling SVN: complete this,
# use %{svn} on line 30, uncomment line 97
%define svn             2601
%define rel		1
%define release 	%mkrel 1.%{svn}.%{rel}

# when compiling stable version
#define rel             1
#define release         %mkrel %{rel}

%define major		2
%define libname		%mklibname %{name}%{major}

%define build_doc 	1

# Macros for in the menu-file.
%define section Applications/Sciences/Biology
%define title   E-cell
%define summary	A software suite for modeling, simulation, and analysis of biological cells

Summary:	%{summary}
Name:		%{name}
Version:	%{version}
Release:	%{release}
# Source0: if stable use %{name}-%{version}.tar.bz2
# if SVN use %{name}-%{version}-%{svn}.tar.bz2
Source0:	%{name}-%{version}-%{svn}.tar.bz2
Source1:	%{name}-icons.tar.bz2
License:	GPL
Group:		Sciences/Biology
Url:		http://ecell.sourceforge.net/
BuildRoot:	%{_tmppath}/%{name}-buildroot
Prefix:		%{_prefix}
Obsoletes:	ecell3 <= 1.0.103
Buildrequires:	python-numeric-devel python-numpy gnome-python-canvas boost-devel gsl-devel
Requires:	gnome-python gnome-python-canvas gnome-python-gnomevfs pygtk2.0-libglade python-numeric python-numpy libsbml
Requires:	%{libname} = %{version}-%{release}
# We need xorg-x11-Xvfb to be able to import gnome.canvas python module during compilation
BuildRequires:	pygtk2.0-libglade libltdl-devel

%description
E-Cell Project is an international research project aiming to model and
reconstruct biological phenomena in silico, and developing necessary
theoretical supports, technologies and software platforms to allow precise
whole cell simulation.
E-Cell System is an object-oriented software suite for modeling, simulation,
and analysis of large scale complex systems such as biological cells. The
first version of E-Cell Simulation Environment (E-Cell SE) was released
in 1999, after which the development of its Windows version, E-Cell
version 2, had started and recently released. Software development has
since shifted to developing version 3, restructuring the system with
an aim to provide the cell simulation community a common, highly
flexible and high performance software environment.

%package -n %{libname}
Summary:	Libraries from Ecell3
Group:		System/Libraries
Provides:	%{libname} = %{version}-%{release}
Obsoletes:	libecell3_%{major} <= 1.0.103
Requires:	libsbml

%description -n %{libname}
This package provides the libraries and includes files from Ecell3.
Note that development libraries and headers are also included in this
package because they may be required to create new biological processes
or to run the included examples.

# Note : do not create a libecell3-devel package
# (see Note in %{libname} description)

%if %build_doc
%package doc
Summary:	Ecell3 extras documentations
Group:		Sciences/Biology
BuildRequires:  tetex-latex graphviz docbook-utils-pdf

%description doc
E-Cell Project is an international research project aiming to model and
reconstruct biological phenomena in silico, and developing necessary
theoretical supports, technologies and software platforms to allow precise
whole cell simulation.

This package contains extra documentation.
%endif

%prep

%setup -q -n %{name}
%setup -q -n %{name} -T -D -a1 #icons

%build

# SVN version
./autogen.sh
#############

## needed for import gnome.canvas python module
#XDISPLAY=$(i=2; while [ -f /tmp/.X$i-lock ]; do i=$(($i+1)); done; echo $i)
#{_prefix}/X11R6/bin/Xvfb :$XDISPLAY &
#export DISPLAY=:$XDISPLAY
## without it, it will not work ( EE was randomly chosen )
#xauth add $DISPLAY . EE

%configure
%make

# no need, it is not created
# kill $(cat /tmp/.X$XDISPLAY-lock)

# make doc-pdf is borked for the moment... but do html and latex doc
%if %build_doc
%make doc
%endif

%install

rm -rf %{buildroot}

%makeinstall
%multiarch_includes $RPM_BUILD_ROOT%{_includedir}/ecell-3.1/ecell_config.h

# Menu
mkdir -p %{buildroot}/%{_menudir}
cat > %{buildroot}/%{_menudir}/%{name} << EOF
?package(%{name}): \
command="%{_bindir}/ecell3-session-monitor" \
needs="X11" \
icon="%name.png" \
section="%section" \
title="%{title}-session-monitor" \
longtitle="%{summary}" \
startup_notify="true" \
xdg="true"
?package(%{name}): \
command="%{_bindir}/ecell3-model-editor" \
needs="X11" \
icon="%name.png" \
section="%section" \
title="%{title}-model-editor" \
longtitle="%{summary}" \
startup_notify="true" \
xdg="true"
EOF

mkdir -p $RPM_BUILD_ROOT%{_datadir}/applications
cat > $RPM_BUILD_ROOT%{_datadir}/applications/mandriva-%{name}-session-monitor.desktop << EOF
[Desktop Entry]
Encoding=UTF-8
Name=E-Cell Session Monitor
Comment=%{summary}
Exec=%{_bindir}/ecell3-session-monitor
Icon=%{name}
Terminal=false 
Type=Application
Categories=Gtk;Science;Biology;X-MandrivaLinux-MoreApplications-Sciences-Biology
EOF
cat > $RPM_BUILD_ROOT%{_datadir}/applications/mandriva-%{name}-model-editor.desktop << EOF
[Desktop Entry]
Encoding=UTF-8
Name=E-Cell Model Editor
Comment=%{summary}
Exec=%{_bindir}/ecell3-model-editor
Icon=%{name}
Terminal=false
Type=Application
Categories=Gtk;Science;Biology;X-MandrivaLinux-MoreApplications-Sciences-Biology
EOF

# icons
%__install -D -m 644 %{name}48.png %{buildroot}/%{_liconsdir}/%{name}.png
%__install -D -m 644 %{name}32.png %{buildroot}/%{_iconsdir}/%{name}.png
%__install -D -m 644 %{name}16.png %{buildroot}/%{_miconsdir}/%{name}.png


%clean
%__rm -rf %{buildroot}

%post
%{update_menus}

%postun
%{clean_menus}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig


%files -n %{name}
%defattr(0755,root,root,0755)
%{_bindir}/*
%defattr(-,root,root)
%doc AUTHORS COPYING INSTALL NEWS README
#samples (E-Cell examples)
%doc doc/sample/ 
%{_datadir}/ecell-3.1
%{_datadir}/applications/*
%{_menudir}/*
%{_iconsdir}/%{name}.png
%{_liconsdir}/%{name}.png
%{_miconsdir}/%{name}.png

%files -n %{libname}
%defattr(-,root,root)
%doc AUTHORS COPYING INSTALL NEWS README
%{_libdir}/ecell-3.1
%{_libdir}/*.so.*
%{_libdir}/python%pyver/site-packages/ecell
# Note: leave dev libraries and includes files in %{libname}
# (see %{libname} description), they are needed for the examples (samples)
%{_libdir}/*.so
%{_libdir}/*.la
%{_includedir}/*

%if %build_doc
%files doc
%defattr(-,root,root)
%doc doc/refman/ doc/users-manual/
%doc AUTHORS COPYING INSTALL NEWS README
%endif

%changelog
* Fri Sep 01 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-1.2601.1mdv2007.0
- new snapshot
- Buildrequires fix

* Fri Aug 18 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-1.2600.2mdv2007.0
- menu entry fix

* Thu Aug 17 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-1.2600.1mdv2007.0
- new snapshot
- some menu cleaning

* Sun Jul 23 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-1.2597.3mdv2007.0
- correct menu entry missing

* Sun Jul 23 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-1.2597.2mdv2007.0
- correct menu entry

* Sat Jul 22 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-1.2597.1mdv2007.0
- new snapshot
- xdg menu

* Wed Jun 28 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-1.2594.1mdv2007.0
- new snapshot
- xdg menu

* Sat Jun 24 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-1.2592.1mdv2007.0
- new snapshot

* Fri Jun 23 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-1.2589.2mdv2007.0
- requires python-numpy

* Fri Jun 23 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-1.2589.1mdv2007.0
- new snapshot

* Sun Apr 23 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-1.2555.1mdk
- switch to SVN repository
- doc_grouped has been removed from repository
- now compile on x86_64

* Fri Feb 17 2006 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-0.20060216.1mdk
- Use %mkrel
- New CVS snapshot
- BuildRequires: xorg-x11-Xvfb and set DISPLAY for gnome.canvas import (from Gcompris spec)

* Mon Dec 19 2005 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-0.20051219.1mdk
- New CVS snapshot

* Sat Dec 10 2005 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-0.20051210.2mdk
- New Requires

* Sat Dec 10 2005 Eric Fernandez <zeb@zebulon.org.uk> 3.1.105-0.20051210.1mdk
- New CVS snapshot

* Thu Nov 24 2005 Eric Fernandez <zeb@zebulon.org.uk> 3.1.104-0.20051124.1mdk
- New CVS snapshot

* Tue Nov 08 2005 Eric Fernandez <zeb@zebulon.org.uk> 3.1.104-0.20051107.1mdk
- Documentation package created
- Spec file cleanup
- New CVS

* Sat Nov 05 2005 Eric Fernandez <zeb@zebulon.org.uk> 3.1.104-0.20051104.2mdk
- Corrects doc building problem

* Sat Nov 05 2005 Eric Fernandez <zeb@zebulon.org.uk> 3.1.104-0.20051104.1mdk
- New 3.1.105 snapshot

* Thu Aug 04 2005 Eric Fernandez <zeb@zebulon.org.uk> 3.1.104-0.20050804.2mdk
- New snapshot, new bug fix

* Sat Jul 30 2005 Eric Fernandez <zeb@zebulon.org.uk> 3.1.104-0.20050730.1mdk
- New snapshot, corrects a nasty bug in ODEStepper

* Mon Jul 25 2005 Eric Fernandez <zeb@zebulon.org.uk> 3.1.104-0.20050725.1mdk
- New snapshot
- Clean up Buildrequires (lib devel requirements)

* Thu Mar 03 2005 Eric Fernandez <zeb@zebulon.org.uk> 3.1.104-0.20050303.1mdk
- New snapshot, CVS version 3.1.104
- multiarch policy

* Wed Jan 19 2005 Eric Fernandez <zeb@zebulon.org.uk> 3.1.103-0.20050118.1mdk
- New snapshot
- removed --with-plf since graphviz has now a free license and is available in main
- rename ecell3 to ecell, obsoletes ecell3, libecell3
- Happy new year :)

* Mon Dec 20 2004  Eric Fernandez <zeb@zebulon.org.uk> 1.0.103-0.20041219.1mdk
- New snapshot
- libecell3 now requires libsbml

* Thu Dec 09 2004  Eric Fernandez <zeb@zebulon.org.uk> 1.0.103-0.20041208.1mdk
- New snapshot
- some spec comments to clarify the status of documentation and some dev libs

* Sun Dec 05 2004 Michael Scherer <misc@mandrake.org> 1.0.103-0.20040930.3mdk
- Rebuild for new  python

* Thu Oct 28 2004 Olivier Thauvin <thauvin@aerov.jussieu.fr> 1.0.103-0.20040930.2mdk
- Requires lib == version (thx Eric Fernandez <zeb@zebulon.org.uk>)

* Sat Oct 02 2004 Olivier Thauvin <thauvin@aerov.jussieu.fr> 1.0.103-0.20040930.1mdk
- Eric Fernandez <zeb@zebulon.org.uk>
  - spec file cleaning, split package
  - New snapshot, fix script use in GUI (osogo)
- add -with doc and --with plf for documantation

* Tue Sep 21 2004 Michael Scherer <misc@mandrake.org> 1.0.103-0.20040914.1mdk 
- spec files cleaning, and fixing
- from Eric Fernandez <zeb@zebulon.org.uk>
  - New snapshot, various fixes

* Mon Sep 13 2004 Eric Fernandez <zeb@zebulon.org.uk> 1.0.103-0.20040913.1mdk
- New snapshot, fix script use in GUI (osogo)

* Thu Sep 09 2004 Eric Fernandez <zeb@zebulon.org.uk> 1.0.103-0.20040909.1mdk
- New snapshot, various bugfixes

* Wed Sep 08 2004 Eric Fernandez <zeb@zebulon.org.uk> 1.0.103-0.20040908.1mdk
- New snapshot, added LocalSimulatorImplementation

* Tue Aug 31 2004 Eric Fernandez <zeb@zebulon.org.uk> 1.0.103-0.20040830-1mdk
- New snapshot (new model editor and tutorial)

* Thu Aug 26 2004 Eric Fernandez <zeb@zebulon.org.uk> 1.0.103-0.20040825-1mdk
- First mdk release
